@@ -9,10 +9,10 @@ This module implements Business Transaction DSL.
 """
 from _stories.argument import arguments
 from _stories.returned import Failure
+from _stories.returned import Next
 from _stories.returned import Result
-from _stories.returned import Skip
 from _stories.returned import Success
 from _stories.story import story
 
 
-__all__ = ["story", "arguments", "Result", "Success", "Failure", "Skip"]
+__all__ = ["story", "arguments", "Result", "Success", "Failure", "Next"]
